import{s as r,b as e,a,S as i}from"./chunk-OW32GOEJ-DwqEHwUM.js";import{_ as s}from"./mermaid-vendor-DEhmckNu.js";import"./chunk-BFAMUDN2-BLZ7l99T.js";import"./chunk-SKB7J2MH-B6gv1oqh.js";import"./feature-graph-CGlNNV88.js";import"./react-vendor-DEwriMA6.js";import"./graph-vendor-B-X5JegA.js";import"./ui-vendor-CeCm8EER.js";import"./utils-vendor-BysuhMZA.js";var f={parser:a,get db(){return new i(2)},renderer:e,styles:r,init:s(t=>{t.state||(t.state={}),t.state.arrowMarkerAbsolute=t.arrowMarkerAbsolute},"init")};export{f as diagram};
